@@ -13,8 +13,11 @@ if __name__ == "__main__":
 
         try:
             infos_question = charger_question(args.fichier, get_readers())
-            resultats = valider_schema_yaml_infos_question(infos_question)
-            resultats["infos_question"] = infos_question
+            if not infos_question:
+                resultats = {"erreurs": {args.fichier: "Format YAML invalide"}}
+            else:
+                resultats = valider_schema_yaml_infos_question(infos_question)
+                resultats["infos_question"] = infos_question
             code_retour = déterminer_code_retour(resultats)
         except (urllib.error.HTTPError, urllib.error.URLError) as e:
             code_retour = 255
